# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blueprint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62lueprint.proto\x12\x13\x63onnector.blueprint\"\x12\n\x10\x42lueprintRequest\"\x13\n\x11\x42lueprintResponse2k\n\x10\x42lueprintService\x12W\n\x04Read\x12%.connector.blueprint.BlueprintRequest\x1a&.connector.blueprint.BlueprintResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'blueprint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BLUEPRINTREQUEST']._serialized_start=40
  _globals['_BLUEPRINTREQUEST']._serialized_end=58
  _globals['_BLUEPRINTRESPONSE']._serialized_start=60
  _globals['_BLUEPRINTRESPONSE']._serialized_end=79
  _globals['_BLUEPRINTSERVICE']._serialized_start=81
  _globals['_BLUEPRINTSERVICE']._serialized_end=188
# @@protoc_insertion_point(module_scope)
