# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: platform.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eplatform.proto\x12\x12\x63onnector.platform\"\x11\n\x0fPlatformRequest\"\x12\n\x10PlatformResponse2f\n\x0fPlatformService\x12S\n\x04Read\x12#.connector.platform.PlatformRequest\x1a$.connector.platform.PlatformResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'platform_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLATFORMREQUEST']._serialized_start=38
  _globals['_PLATFORMREQUEST']._serialized_end=55
  _globals['_PLATFORMRESPONSE']._serialized_start=57
  _globals['_PLATFORMRESPONSE']._serialized_end=75
  _globals['_PLATFORMSERVICE']._serialized_start=77
  _globals['_PLATFORMSERVICE']._serialized_end=179
# @@protoc_insertion_point(module_scope)
