# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: company.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcompany.proto\x12\x11\x63onnector.company\"\x10\n\x0e\x43ompanyRequest\"\x11\n\x0f\x43ompanyResponse2\xd1\x02\n\x0e\x43ompanyService\x12L\n\x03Get\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponse\x12O\n\x06\x43reate\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponse\x12O\n\x04Read\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponse0\x01\x12O\n\x06Update\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'company_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPANYREQUEST']._serialized_start=36
  _globals['_COMPANYREQUEST']._serialized_end=52
  _globals['_COMPANYRESPONSE']._serialized_start=54
  _globals['_COMPANYRESPONSE']._serialized_end=71
  _globals['_COMPANYSERVICE']._serialized_start=74
  _globals['_COMPANYSERVICE']._serialized_end=411
# @@protoc_insertion_point(module_scope)
